@@ -13,7 +13,7 @@ def get_handlers(context: Any) -> HandlerList:
         if you use config `ICON_IMAGE_LOCAL_PATH` specify local filesystem favicon.ico full-path and that file is exist
         use local filesystem file response /favicon.ico request
         if you do not specify `ICON_IMAGE_LOCAL_PATH` config or that file do not exist,
-        will use loader to try get favicon.ico
+        will use loader to try to get favicon.ico
     """
-    logger.debug("[icon-handler] init /favicon.icon handler")
+    logger.debug("[thumbor-icon-handler] init /favicon.ico handler")
     return [("/favicon.ico", IconHandler, {"context": context})]
